@@ -1,4 +1,4 @@
 from .logger import Logger
 from .web import Web
 from .html import Html
-from .drivers import FirefoxDriver, UndetectedChromeDriver
+from .drivers import FirefoxDriver, ChromeDriver, UndetectedChromeDriver
